@@ -128,7 +128,7 @@ static void saveconfig(GtkWidget *wid, gpointer data)
 			md5_append(&md5state, (unsigned const char *)pwd, strlen(pwd));
 			md5_finish(&md5state, md5pword);
 			xmms_cfg_write_string(cfgfile, "audioscrobbler", "password",
-					(char *)hexify(md5pword, sizeof(md5pword)));
+					(char *)hexify((char *)md5pword, sizeof(md5pword)));
 		}
 #ifdef MAKE_XMMS
 		xmms_cfg_write_default_file(cfgfile);
