@@ -208,7 +208,7 @@ static int sc_parse_hs_res(void)
 	return -1;
 }
 
-static void hexify(char *pass, int len)
+static void hexify(unsigned char *pass, int len)
 {
 	char *bp = sc_response_hash;
 	char hexchars[] = "0123456789abcdef";
@@ -488,6 +488,7 @@ static void sc_handlequeue(pthread_mutex_t mutex)
 {
 	GString *submitentry;
 	int nsubmit;
+	int i;
 	int wait;
 
 	if(sc_submit_timeout < time(NULL) && sc_bad_users < 3)
@@ -512,7 +513,12 @@ static void sc_handlequeue(pthread_mutex_t mutex)
 				pthread_mutex_lock(&mutex);
 
 #ifdef ALLOW_MULTIPLE
-				q_free();
+				if (nsubmit < q_len()) {
+					for (i=0; i<nsubmit; i++)
+						q_get();
+				} else {
+					q_free();
+				}
 #else
 				q_get();
 #endif
