@@ -1,5 +1,5 @@
-#ifndef NET_H
-#define NET_H 1
+#ifndef SCROBBLER_H
+#define SCROBBLER_H 1
 int sc_idle(pthread_mutex_t);
 void sc_init(char *, char *);
 void sc_addentry(pthread_mutex_t, metatag_t *, int);
