@@ -27,6 +27,7 @@
 #include "../fmt.h"
 #include "../config.h"
 #include "include/unicode.h"
+#include "include/tags.h"
 #define BUFFER_SIZE 4096
 
 #ifdef MAKE_BMP
@@ -39,26 +40,11 @@
 #define FILE VFSFile
 #endif
 
-/*
- * Determining if a CD is being played is left up to the reader.
- *
- 
-int cdaudio_find(char *filename)
-{
-	We've got to find a way to ensure this works on all platforms. 
-	
-	return !(fmt_strcasecmp(strrchr(filename, '.') + 1, "cda"));
-}
-*/
-
-cdaudio_t *readCDAudio(char *filename, char track)
+int fetchCDAudio(metatag_t *meta, char *filename, char track)
 {
 	int retVal;
 	musicbrainz_t mb;
 	char *tmp;
-	cdaudio_t *musicbrainz = calloc(sizeof(cdaudio_t), 1);
-	
-	memset(musicbrainz, 0, sizeof(cdaudio_t));
 	
 	tmp = malloc(BUFFER_SIZE / 4 + 1);
 	mb = mb_New();
@@ -75,8 +61,7 @@ cdaudio_t *readCDAudio(char *filename, char track)
 #endif
 		mb_Delete(mb);
 		free(tmp);
-		free(musicbrainz);
-		return NULL;
+		return 0;
 	}
 	pdebug("Selecting result...", META_DEBUG);
 	retVal = mb_Select1(mb, MBS_SelectAlbum, 1);
@@ -85,8 +70,7 @@ cdaudio_t *readCDAudio(char *filename, char track)
 		pdebug("ERROR: Album select failed.", META_DEBUG);
 		mb_Delete(mb);
 		free(tmp);
-		free(musicbrainz);
-		return NULL;
+		return 0;
 	}
 	pdebug("Extracting MusicBrainz data from result...", META_DEBUG);
 	memset(tmp, '\0', BUFFER_SIZE / 4 + 1);
@@ -94,60 +78,33 @@ cdaudio_t *readCDAudio(char *filename, char track)
 	if(retVal == 0)
 	{
 		pdebug("ERROR: Album title not found.", META_DEBUG);
-		musicbrainz->album = calloc(1, 1);
 	}
 	else
 	{
-		musicbrainz->album = malloc(strlen(tmp) + 1);
-		strcpy(musicbrainz->album, tmp);
+		metatag_set_album(meta, tmp);
 	}
 	memset(tmp, '\0', BUFFER_SIZE / 4 + 1);
 	retVal = mb_GetResultData1(mb, MBE_AlbumGetArtistName, tmp, BUFFER_SIZE / 4, track);
 	if(retVal == 0)
 	{
 		pdebug("ERROR: Artist name not found.", META_DEBUG);
-		musicbrainz->artist = calloc(1, 1);
 	}
 	else
 	{
-		musicbrainz->artist = malloc(strlen(tmp) + 1);
-		strcpy(musicbrainz->artist, tmp);
+		metatag_set_artist(meta, tmp);
 	}
 	memset(tmp, '\0', BUFFER_SIZE / 4 + 1);
 	retVal = mb_GetResultData1(mb, MBE_AlbumGetTrackName, tmp, BUFFER_SIZE / 4, track);
 	if(retVal == 0)
 	{
 		pdebug("ERROR: Track title not found.", META_DEBUG);
-		musicbrainz->title = calloc(1, 1);
 	}
 	else
 	{
-		musicbrainz->title = malloc(strlen(tmp) + 1);
-		strcpy(musicbrainz->title, tmp);
-	}
-	memset(tmp, '\0', BUFFER_SIZE / 4 + 1);
-	retVal = mb_GetResultData1(mb, MBE_AlbumGetTrackId, tmp, BUFFER_SIZE / 4, track);
-	if(retVal == 0)
-	{
-		pdebug("ERROR: MBID not found.", META_DEBUG);
-		musicbrainz->mbid = calloc(1, 1);
-	}
-	else
-	{
-		musicbrainz->mbid = malloc(64);
-		mb_GetIDFromURL(mb, tmp, musicbrainz->mbid, 64);
+		metatag_set_title(meta, tmp);
 	}
 	mb_Delete(mb);
 	free(tmp);
 	
-	return musicbrainz;
-}
-
-void freeCDAudio(cdaudio_t *musicbrainz)
-{
-	free(musicbrainz->mbid);
-	free(musicbrainz->title);
-	free(musicbrainz->artist);
-	free(musicbrainz->album);
-	free(musicbrainz);
+	return 1;
 }
