@@ -18,14 +18,10 @@
  *
  */
 
+#include "tags.h"
+
 #ifndef CDAUDIO_H
 #define CDAUDIO_H 1
 
-typedef struct
-{
-	unsigned char *title, *artist, *album, *mbid;
-} cdaudio_t;
-
-cdaudio_t *readCDAudio(char *, char);
-void freeCDAudio(cdaudio_t *);
+int fetchCDAudio(metatag_t *, char *, char);
 #endif
